@@ -12,15 +12,14 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/bin',
- 'BINLIBDEST': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10',
+ 'BINDIR': '/src/build_linux/deps/Release/python/bin',
+ 'BINLIBDEST': '/src/build_linux/deps/Release/python/lib/python3.10',
  'BLDLIBRARY': 'libpython3.10.a',
- 'BLDSHARED': 'gcc -pthread -shared '
-              '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-              '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-              '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-              '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-              '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+ 'BLDSHARED': 'gcc -pthread -shared -L/src/build_linux/deps/Release/ffi/lib '
+              '-L/src/build_linux/deps/Release/sqlite/lib '
+              '-L/src/build_linux/deps/Release/bzip2/lib '
+              '-L/src/build_linux/deps/Release/lzma/lib '
+              '-L/src/build_linux/deps/Release/zlib/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
@@ -28,77 +27,69 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-           '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-           '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-           '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-           '-fPIC -fPIC',
+           '-I/src/build_linux/deps/Release/sqlite/include '
+           '-I/src/build_linux/deps/Release/bzip2/include '
+           '-I/src/build_linux/deps/Release/lzma/include '
+           '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                     '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                     '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                     '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                     '-fPIC',
+ 'CONFIGURE_CFLAGS': '-I/src/build_linux/deps/Release/sqlite/include '
+                     '-I/src/build_linux/deps/Release/bzip2/include '
+                     '-I/src/build_linux/deps/Release/lzma/include '
+                     '-I/src/build_linux/deps/Release/zlib/include -fPIC',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                       '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                       '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                       '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                       '-fPIC',
- 'CONFIGURE_LDFLAGS': '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-                      '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-                      '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-                      '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-                      '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+ 'CONFIGURE_CPPFLAGS': '-I/src/build_linux/deps/Release/sqlite/include '
+                       '-I/src/build_linux/deps/Release/bzip2/include '
+                       '-I/src/build_linux/deps/Release/lzma/include '
+                       '-I/src/build_linux/deps/Release/zlib/include -fPIC',
+ 'CONFIGURE_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
+                      '-L/src/build_linux/deps/Release/sqlite/lib '
+                      '-L/src/build_linux/deps/Release/bzip2/lib '
+                      '-L/src/build_linux/deps/Release/lzma/lib '
+                      '-L/src/build_linux/deps/Release/zlib/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python' "
-                "'--with-openssl=/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ssl' "
-                "'CFLAGS=-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include "
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                "-fPIC' "
-                "'LDFLAGS=-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib "
-                '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-                '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-                '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-                '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib '
-                "' "
-                "'CPPFLAGS=-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include "
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                "-fPIC' "
-                "'PKG_CONFIG_PATH=/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib/pkgconfig'",
- 'CONFINCLUDEDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include',
- 'CONFINCLUDEPY': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include/python3.10',
+ 'CONFIG_ARGS': "'--prefix=/src/build_linux/deps/Release/python' "
+                "'--with-openssl=/src/build_linux/deps/Release/ssl' "
+                "'CFLAGS=-I/src/build_linux/deps/Release/sqlite/include "
+                '-I/src/build_linux/deps/Release/bzip2/include '
+                '-I/src/build_linux/deps/Release/lzma/include '
+                "-I/src/build_linux/deps/Release/zlib/include -fPIC' "
+                "'LDFLAGS=-L/src/build_linux/deps/Release/ffi/lib "
+                '-L/src/build_linux/deps/Release/sqlite/lib '
+                '-L/src/build_linux/deps/Release/bzip2/lib '
+                '-L/src/build_linux/deps/Release/lzma/lib '
+                "-L/src/build_linux/deps/Release/zlib/lib ' "
+                "'CPPFLAGS=-I/src/build_linux/deps/Release/sqlite/include "
+                '-I/src/build_linux/deps/Release/bzip2/include '
+                '-I/src/build_linux/deps/Release/lzma/include '
+                "-I/src/build_linux/deps/Release/zlib/include -fPIC' "
+                "'PKG_CONFIG_PATH=/src/build_linux/deps/Release/ffi/lib/pkgconfig'",
+ 'CONFINCLUDEDIR': '/src/build_linux/deps/Release/python/include',
+ 'CONFINCLUDEPY': '/src/build_linux/deps/Release/python/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/build/python/src/external_python/coverage.info',
- 'COVERAGE_REPORT': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/build/python/src/external_python/lcov-report',
+ 'COVERAGE_INFO': '/src/build_linux/deps/build/python/src/external_python/coverage.info',
+ 'COVERAGE_REPORT': '/src/build_linux/deps/build/python/src/external_python/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include '
-             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-             '-fPIC',
+ 'CPPFLAGS': '-I. -I./Include -I/src/build_linux/deps/Release/sqlite/include '
+             '-I/src/build_linux/deps/Release/bzip2/include '
+             '-I/src/build_linux/deps/Release/lzma/include '
+             '-I/src/build_linux/deps/Release/zlib/include -fPIC',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python '
-             '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib '
-             '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10 '
-             '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10/lib-dynload',
- 'DESTLIB': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10',
+ 'DESTDIRS': '/src/build_linux/deps/Release/python '
+             '/src/build_linux/deps/Release/python/lib '
+             '/src/build_linux/deps/Release/python/lib/python3.10 '
+             '/src/build_linux/deps/Release/python/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/src/build_linux/deps/Release/python/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10/lib-dynload',
+ 'DESTSHARED': '/src/build_linux/deps/Release/python/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -321,6 +312,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBUUID': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 0,
@@ -483,6 +475,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -564,45 +557,44 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include '
-                   '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include '
-                   '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include/python3.10 '
-                   '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include/python3.10',
- 'INCLUDEDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include',
- 'INCLUDEPY': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/include/python3.10',
- 'INSTALL': '/bin/install -c',
- 'INSTALL_DATA': '/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/bin/install -c',
- 'INSTALL_SCRIPT': '/bin/install -c',
- 'INSTALL_SHARED': '/bin/install -c -m 755',
+ 'INCLDIRSTOMAKE': '/src/build_linux/deps/Release/python/include '
+                   '/src/build_linux/deps/Release/python/include '
+                   '/src/build_linux/deps/Release/python/include/python3.10 '
+                   '/src/build_linux/deps/Release/python/include/python3.10',
+ 'INCLUDEDIR': '/src/build_linux/deps/Release/python/include',
+ 'INCLUDEPY': '/src/build_linux/deps/Release/python/include/python3.10',
+ 'INSTALL': '/usr/bin/install -c',
+ 'INSTALL_DATA': '/usr/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c',
+ 'INSTALL_SHARED': '/usr/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.10.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-            '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-            '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-            '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-            '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+ 'LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
+            '-L/src/build_linux/deps/Release/sqlite/lib '
+            '-L/src/build_linux/deps/Release/bzip2/lib '
+            '-L/src/build_linux/deps/Release/lzma/lib '
+            '-L/src/build_linux/deps/Release/zlib/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.10.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared '
-             '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-             '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-             '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-             '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-             '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+ 'LDSHARED': 'gcc -pthread -shared -L/src/build_linux/deps/Release/ffi/lib '
+             '-L/src/build_linux/deps/Release/sqlite/lib '
+             '-L/src/build_linux/deps/Release/bzip2/lib '
+             '-L/src/build_linux/deps/Release/lzma/lib '
+             '-L/src/build_linux/deps/Release/zlib/lib',
  'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10',
- 'LIBDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib',
- 'LIBFFI_INCLUDEDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/include',
+ 'LIBDEST': '/src/build_linux/deps/Release/python/lib/python3.10',
+ 'LIBDIR': '/src/build_linux/deps/Release/python/lib',
+ 'LIBFFI_INCLUDEDIR': '/src/build_linux/deps/Release/ffi/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/pkgconfig',
- 'LIBPL': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10/config-3.10-x86_64-linux-gnu',
+ 'LIBPC': '/src/build_linux/deps/Release/python/lib/pkgconfig',
+ 'LIBPL': '/src/build_linux/deps/Release/python/lib/python3.10/config-3.10-x86_64-linux-gnu',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.10.a',
  'LIBRARY_DEPS': 'libpython3.10.a',
@@ -621,14 +613,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib/python3.10',
+ 'MACHDESTLIB': '/src/build_linux/deps/Release/python/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/share/man',
- 'MKDIR_P': '/bin/mkdir -p',
+ 'MANDIR': '/src/build_linux/deps/Release/python/share/man',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
@@ -653,8 +645,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ssl/include',
- 'OPENSSL_LDFLAGS': '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ssl/lib',
+ 'OPENSSL_INCLUDES': '-I/src/build_linux/deps/Release/ssl/include',
+ 'OPENSSL_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
@@ -693,84 +685,80 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
+                             '-I/src/build_linux/deps/Release/sqlite/include '
+                             '-I/src/build_linux/deps/Release/bzip2/include '
+                             '-I/src/build_linux/deps/Release/lzma/include '
+                             '-I/src/build_linux/deps/Release/zlib/include '
                              '-fPIC -fPIC -std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                             '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
+                             '-I/src/build_linux/deps/Release/sqlite/include '
+                             '-I/src/build_linux/deps/Release/bzip2/include '
+                             '-I/src/build_linux/deps/Release/lzma/include '
+                             '-I/src/build_linux/deps/Release/zlib/include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-              '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-              '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-              '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-              '-fPIC -fPIC',
+              '-I/src/build_linux/deps/Release/sqlite/include '
+              '-I/src/build_linux/deps/Release/bzip2/include '
+              '-I/src/build_linux/deps/Release/lzma/include '
+              '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                   '-fPIC -fPIC -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wall -I/src/build_linux/deps/Release/sqlite/include '
+                   '-I/src/build_linux/deps/Release/bzip2/include '
+                   '-I/src/build_linux/deps/Release/lzma/include '
+                   '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                   '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                   '-fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-                    '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-                    '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-                    '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-                    '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+                   '-I/src/build_linux/deps/Release/sqlite/include '
+                   '-I/src/build_linux/deps/Release/bzip2/include '
+                   '-I/src/build_linux/deps/Release/lzma/include '
+                   '-I/src/build_linux/deps/Release/zlib/include -fPIC '
+                   '-DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
+                    '-L/src/build_linux/deps/Release/sqlite/lib '
+                    '-L/src/build_linux/deps/Release/bzip2/lib '
+                    '-L/src/build_linux/deps/Release/lzma/lib '
+                    '-L/src/build_linux/deps/Release/zlib/lib',
  'PY_CPPFLAGS': '-I. -I./Include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                '-fPIC',
+                '-I/src/build_linux/deps/Release/sqlite/include '
+                '-I/src/build_linux/deps/Release/bzip2/include '
+                '-I/src/build_linux/deps/Release/lzma/include '
+                '-I/src/build_linux/deps/Release/zlib/include -fPIC',
  'PY_ENABLE_SHARED': 0,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/ffi/lib '
-               '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/lib '
-               '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/lib '
-               '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/lib '
-               '-L/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/lib',
+ 'PY_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
+               '-L/src/build_linux/deps/Release/sqlite/lib '
+               '-L/src/build_linux/deps/Release/bzip2/lib '
+               '-L/src/build_linux/deps/Release/lzma/lib '
+               '-L/src/build_linux/deps/Release/zlib/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                        '-fPIC -fPIC -std=c99 -Wextra -Wno-unused-result '
+                        '-I/src/build_linux/deps/Release/sqlite/include '
+                        '-I/src/build_linux/deps/Release/bzip2/include '
+                        '-I/src/build_linux/deps/Release/lzma/include '
+                        '-I/src/build_linux/deps/Release/zlib/include -fPIC '
+                        '-fPIC -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/sqlite/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/bzip2/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/lzma/include '
-                        '-I/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/zlib/include '
-                        '-fPIC',
+                        '-I/src/build_linux/deps/Release/sqlite/include '
+                        '-I/src/build_linux/deps/Release/bzip2/include '
+                        '-I/src/build_linux/deps/Release/lzma/include '
+                        '-I/src/build_linux/deps/Release/zlib/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
@@ -780,7 +768,7 @@ build_time_vars = {'ABIFLAGS': '',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
- 'SCRIPTDIR': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/lib',
+ 'SCRIPTDIR': '/src/build_linux/deps/Release/python/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
@@ -850,9 +838,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/build/python/src/external_python',
- 'abs_srcdir': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/build/python/src/external_python',
- 'datarootdir': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python/share',
- 'exec_prefix': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python',
- 'prefix': '/home/sybren/buildbot-builder/linux_glibc217_x86_64_cmake/build_deps/deps/Release/python',
+ 'abs_builddir': '/src/build_linux/deps/build/python/src/external_python',
+ 'abs_srcdir': '/src/build_linux/deps/build/python/src/external_python',
+ 'datarootdir': '/src/build_linux/deps/Release/python/share',
+ 'exec_prefix': '/src/build_linux/deps/Release/python',
+ 'prefix': '/src/build_linux/deps/Release/python',
  'srcdir': '.'}
